==> fet_3.12.30.orig.tar.gz: fet-3.12.30/src/interface/addconstraintminimizenumberofroomsforstudentsform.cpp <==
/***************************************************************************
                          addconstraintminimizenumberofroomsforstudentsform.cpp  -  description
                             -------------------
    begin                : 6 Feb. 2005
    copyright            : (C) 2005 by Liviu Lalescu
    email                : liviu@lalescu.ro
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "addconstraintminimizenumberofroomsforstudentsform.h"
#include "spaceconstraint.h"

#include <qradiobutton.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qtable.h>

AddConstraintMinimizeNumberOfRoomsForStudentsForm::AddConstraintMinimizeNumberOfRoomsForStudentsForm()
{
}

AddConstraintMinimizeNumberOfRoomsForStudentsForm::~AddConstraintMinimizeNumberOfRoomsForStudentsForm()
{
}

void AddConstraintMinimizeNumberOfRoomsForStudentsForm::addConstraint()
{
	SpaceConstraint *ctr=NULL;

	double weight;
	QString tmp=weightLineEdit->text();
	sscanf(tmp, "%lf", &weight);
	if(weight<=0.0){
		QMessageBox::warning(this, QObject::tr("FET information"),
			QObject::tr("Invalid weight"));
		return;
	}

	bool compulsory=false;
	if(compulsoryCheckBox->isChecked())
		compulsory=true;

	ctr=new ConstraintMinimizeNumberOfRoomsForStudents(weight, compulsory);

	bool tmp2=gt.rules.addSpaceConstraint(ctr);
	if(tmp2){
		QString s=QObject::tr("Constraint added:");
		s+="\n";
		s+=ctr->getDetailedDescription(gt.rules);
		QMessageBox::information(this, QObject::tr("FET information"), s);
	}
	else{
		QMessageBox::warning(this, QObject::tr("FET information"),
			QObject::tr("Constraint NOT added - please report error"));
		delete ctr;
	}
}

==> fet_3.18.2.orig.tar.gz: fet-3.18.2/src/interface/addconstraintminimizenumberofroomsforstudentsform.cpp <==
/***************************************************************************
                          addconstraintminimizenumberofroomsforstudentsform.cpp  -  description
                             -------------------
    begin                : 6 Feb. 2005
    copyright            : (C) 2005 by Liviu Lalescu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "addconstraintminimizenumberofroomsforstudentsform.h"
#include "spaceconstraint.h"

#include <qradiobutton.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qtable.h>

AddConstraintMinimizeNumberOfRoomsForStudentsForm::AddConstraintMinimizeNumberOfRoomsForStudentsForm()
{
}

AddConstraintMinimizeNumberOfRoomsForStudentsForm::~AddConstraintMinimizeNumberOfRoomsForStudentsForm()
{
}

void AddConstraintMinimizeNumberOfRoomsForStudentsForm::addConstraint()
{
	SpaceConstraint *ctr=NULL;

	double weight;
	QString tmp=weightLineEdit->text();
	sscanf(tmp, "%lf", &weight);
	if(weight<0.0){
		QMessageBox::warning(this, QObject::tr("FET information"),
			QObject::tr("Invalid weight"));
		return;
	}

	bool compulsory=false;
	if(compulsoryCheckBox->isChecked())
		compulsory=true;

	ctr=new ConstraintMinimizeNumberOfRoomsForStudents(weight, compulsory);

	bool tmp2=gt.rules.addSpaceConstraint(ctr);
	if(tmp2){
		QString s=QObject::tr("Constraint added:");
		s+="\n";
		s+=ctr->getDetailedDescription(gt.rules);
		QMessageBox::information(this, QObject::tr("FET information"), s);
	}
	else{
		QMessageBox::warning(this, QObject::tr("FET information"),
			QObject::tr("Constraint NOT added - please report error"));
		delete ctr;
	}
}
